Error

Enum Error 

#[repr(u32)]
pub enum Error { NotInitialized = 12_389, InvalidArgument = 12_390, OutOfMemory = 12_391, PeerListFull = 12_392, NotFound = 12_393, Internal = 12_394, PeerExists = 12_395, InterfaceMismatch = 12_396, Other(u32), }
Available on crate features esp-now and unstable only.
Internal errors that can occur with ESP-NOW.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Variants



NotInitialized = 12_389

ESP-NOW is not initialized.



InvalidArgument = 12_390

Invalid argument.



OutOfMemory = 12_391

Indicates that there was insufficient memory to complete the operation.



PeerListFull = 12_392

ESP-NOW peer list is full.



NotFound = 12_393

ESP-NOW peer is not found.



Internal = 12_394

Internal error.



PeerExists = 12_395

ESP-NOW peer already exists.



InterfaceMismatch = 12_396

The Wi-Fi interface used for ESP-NOW doesn’t match the expected one for the peer.



Other(u32)

Represents any other error not covered by the above variants, with an associated error code: {0}.